Compatibilité EAC-CPF
=====================

Le tableau ci-dessous référence les `balises XML du format EAC-CPF`_ prises en
compte ou non au moment de l'import. Les points ``.`` indiquent
que la balise est prise en compte (pour certaines partiellement). Les ``x``
indiquent que la balise n'est pas prise en compte, les ``-`` qu'elle ne l'est
que partiellement.

.. _`balises XML du format EAC-CPF`: http://eac.staatsbibliothek-berlin.de/fileadmin/user_upload/schema/cpfTagLibrary.html

===== ==========================
Sup.       Éléments EAC-CPF     
===== ==========================
  .          abbreviation       
  .            abstract         
  .            address          
  .          addressLine        
  x           agencyCode        
  x           agencyName        
  .             agent           
  .           agentType         
  .        alternativeForm      
  x         alternativeSet      
  .         authorizedForm      
  .            biogHist         
  .           chronItem
  .           chronList
  .            citation         
  x         componentEntry      
  .            control          
  .     conventionDeclaration
  .         cpfDescription      
  .          cpfRelation        
  .              date           
  .           dateRange         
  .            dateSet          
  .          description        
  .        descriptiveNote      
  .            eac-cpf          
  .            entityId         
  .           entityType        
  .             event
  .         eventDateTime       
  .        eventDescription     
  .           eventType         
  .           existDates        
  .            fromDate         
  .            function         
  .        functionRelation     
  .           functions         
  .         generalContext      
  .            identity         
  .              item           
  .            language         
  x      languageDeclaration    
  .         languagesUsed       
  .          languageUsed       
  .          legalStatus        
  .         legalStatuses       
  x             level           
  .              list           
  x          localControl       
  x        localDescription     
  x       localDescriptions     
  x      localTypeDeclaration   
  x       maintenanceAgency     
  .        maintenanceEvent     
  .       maintenanceHistory    
  x       maintenanceStatus     
  .            mandate          
  .            mandates         
  x       multipleIdentities    
  .           nameEntry         
  .       nameEntryParallel     
  x         objectBinWrap       
  .         objectXMLWrap       
  .           occupation        
  .          occupations        
  x        otherAgencyCode      
  .         otherRecordId       
  x            outline          
  .               p             
  .              part           
  .             place           
  .           placeEntry        
  .           placeRole         
  .             places          
  .         preferredForm       
  x       publicationStatus     
  .            recordId         
  .         relationEntry       
  .           relations         
  .        resourceRelation     
  x             script          
  x          setComponent       
  .             source          
  .          sourceEntry        
  .            sources          
  .              span           
  .      structureOrGenealogy   
  .              term           
  .             toDate          
  .            useDates         
===== ==========================


===== ==========================
Sup.       Attributs EAC-CPF    
===== ==========================
  x     @accuracy               
  x     @altitude               
  x     @countryCode            
  .     @cpfRelationType        
  .     @functionRelationType   
  x     @identityType           
  x     @languageCode           
  x     @lastDateTimeVerified   
  .     @latitude               
  \-    @localType              
  .     @longitude              
  x     @notAfter               
  x     @notBefore              
  .     @resourceRelationType   
  x     @scriptCode             
  .     @standardDate           
  .     @standardDateTime       
  x     @style                  
  x     @transliteration        
  .     @vocabularySource       
  x     @xlink:actuate          
  x     @xlink:arcrole          
  \-    @xlink:href             
  \-    @xlink:role             
  x     @xlink:show             
  x     @xlink:title            
  x     @xlink:type             
  x     @xml:base               
  x     @xml:id                 
  x     @xml:lang               
===== ==========================
